==> facebookads-2.6.0.tar.gz: facebookads-2.6.0/examples/docs/CUSTOM_AUDIENCE_USERS_ADD_MULTIKEY.py <==
# Copyright 2014 Facebook, Inc.

# You are hereby granted a non-exclusive, worldwide, royalty-free license to
# use, copy, modify, and distribute this software in source code or binary
# form for use in connection with the web services and APIs provided by
# Facebook.

# As with any software that integrates with the Facebook platform, your use
# of this software is subject to the Facebook Developer Principles and
# Policies [http://developers.facebook.com/policy/]. This copyright notice
# shall be included in all copies or substantial portions of the software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from examples.docs import fixtures

custom_audience_id = fixtures.create_custom_audience().get_id_assured()

# _DOC oncall [ritu]
# _DOC open [CUSTOM_AUDIENCE_USERS_ADD_MULTIKEY]
# _DOC vars [custom_audience_id:s]
from facebookads.objects import CustomAudience

audience = CustomAudience(custom_audience_id)
users = [['FirstName', 'test2@example.com', 'LastName1'],
         ['FirstNameTets', 'test2@example.com', 'LastNameTest']]

schema = ['FN', 'EMAIL', 'LN']
audience.add_users(schema, users, is_raw=True)
# _DOC close [CUSTOM_AUDIENCE_USERS_ADD_MULTIKEY]

==> facebookads-2.6.2.tar.gz: facebookads-2.6.2/examples/docs/CUSTOM_AUDIENCE_USERS_ADD_MULTIKEY.py <==
# Copyright 2014 Facebook, Inc.

# You are hereby granted a non-exclusive, worldwide, royalty-free license to
# use, copy, modify, and distribute this software in source code or binary
# form for use in connection with the web services and APIs provided by
# Facebook.

# As with any software that integrates with the Facebook platform, your use
# of this software is subject to the Facebook Developer Principles and
# Policies [http://developers.facebook.com/policy/]. This copyright notice
# shall be included in all copies or substantial portions of the software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from examples.docs import fixtures

custom_audience_id = fixtures.create_custom_audience().get_id_assured()

# _DOC oncall [alexlupu]
# _DOC open [CUSTOM_AUDIENCE_USERS_ADD_MULTIKEY]
# _DOC vars [custom_audience_id:s]
from facebookads.objects import CustomAudience

audience = CustomAudience(custom_audience_id)
users = [['FirstName', 'test2@example.com', 'LastName1'],
         ['FirstNameTest', 'test2@example.com', 'LastNameTest']]

schema = [CustomAudience.Schema.MultiKeySchema.fn,
          CustomAudience.Schema.MultiKeySchema.email,
          CustomAudience.Schema.MultiKeySchema.ln,
          ]
audience.add_users(schema, users, is_raw=True)
# _DOC close [CUSTOM_AUDIENCE_USERS_ADD_MULTIKEY]
